# fastapi_scaffold_generator/generator.py

import os

def create_fastapi_structure(project_name: str):
    structure = [
        f"{project_name}/app/main.py",
        f"{project_name}/app/api/deps.py",
        f"{project_name}/app/api/v1/router.py",
        f"{project_name}/app/api/v1/endpoints/hello.py",
        f"{project_name}/app/api/v1/endpoints/users.py",
        f"{project_name}/app/core/config.py",
        f"{project_name}/app/core/logging_config.py",
        f"{project_name}/app/security/__init__.py",
        f"{project_name}/app/security/auth.py",
        f"{project_name}/app/security/hash.py",
        f"{project_name}/app/security/jwt_handler.py",
        f"{project_name}/app/db/base.py",
        f"{project_name}/app/db/session.py",
        f"{project_name}/app/db/init_db.py",
        f"{project_name}/app/models/user.py",
        f"{project_name}/app/schemas/user.py",
        f"{project_name}/app/schemas/token.py",
        f"{project_name}/app/schemas/__init__.py",
        f"{project_name}/app/services/user_service.py",
        f"{project_name}/app/middleware/cors.py",
        f"{project_name}/app/exceptions/handlers.py",
        f"{project_name}/alembic/versions/.gitkeep",
        f"{project_name}/tests/test_users.py",
        f"{project_name}/.env",
        f"{project_name}/alembic.ini",
        f"{project_name}/docker-compose.yml",
        f"{project_name}/Dockerfile",
        f"{project_name}/gunicorn_conf.py",
        f"{project_name}/requirements.txt",
        f"{project_name}/README.md",
    ]

    for path in structure:
        dir_path = os.path.dirname(path)
        os.makedirs(dir_path, exist_ok=True)
        if not path.endswith("/.gitkeep"):
            with open(path, "w", encoding="utf-8") as f:
                f.write("")

    print(f"✅ FastAPI project '{project_name}' structure created.")
